    // 初始化数据
        let currentPage = 0;
        let startX = 0;
        let icons = JSON.parse(localStorage.getItem('icons')) || [
            { iconUrl: 'https://fonts.googleapis.com/icon?family=Material+Icons', pageUrl: 'installer.html', name: '安装程序' },
            { iconUrl: 'https://fonts.googleapis.com/icon?family=Material+Icons', pageUrl: 'gallery.html', name: '相册' },
            { iconUrl: 'https://fonts.googleapis.com/icon?family=Material+Icons', pageUrl: 'browser.html', name: '浏览器' },
            { iconUrl: 'https://fonts.googleapis.com/icon?family=Material+Icons', pageUrl: 'Calculator.html', name: '计算器' },
            { iconUrl: 'https://fonts.googleapis.com/icon?family=Material+Icons', pageUrl: 'clock.html', name: '时钟' }
        ];
        const pages = document.querySelectorAll('.page');
        const pageContainer = document.querySelector('.page-container');
        
        // 更新时间
        function updateTime() {
            const now = new Date();
            const timeStr = now.toLocaleTimeString('zh-CN', { hour: '2-digit', minute: '2-digit' });
            const dateStr = now.toLocaleDateString('zh-CN', { year: 'numeric', month: 'long', day: 'numeric' });
            
            document.getElementById('time').textContent = timeStr;
            document.getElementById('clock').textContent = timeStr;
            document.getElementById('date').textContent = dateStr;
        }
        
        setInterval(updateTime, 1000);
        updateTime();

        // 获取电池信息
        if ('getBattery' in navigator) {
            navigator.getBattery().then(battery => {
                document.getElementById('battery').textContent = Math.round(battery.level * 100) + '%';
            });
        }

        // 页面滑动
        desktop.addEventListener('touchstart', e => {
            startX = e.touches[0].clientX;
        });

        desktop.addEventListener('touchmove', e => {
            const diff = startX - e.touches[0].clientX;
            if (Math.abs(diff) > 50) {
                const newPage = diff > 0 ? Math.min(currentPage + 1, pages.length - 1) : Math.max(currentPage - 1, 0);
                if (newPage !== currentPage) {
                    currentPage = newPage;
                    pageContainer.style.transform = `translateX(-${currentPage * 100}%)`;
                    updatePageIndicator();
                }
            }
        });

        function updatePageIndicator() {
            document.querySelectorAll('.page-dot').forEach((dot, index) => {
                dot.classList.toggle('active', index === currentPage);
            });
        }

        // 长按桌面显示菜单
        let longPressTimer;
        desktop.addEventListener('touchstart', e => {
            longPressTimer = setTimeout(() => {
                document.getElementById('contextMenu').classList.add('active');
            }, 500);
        });

        desktop.addEventListener('touchend', () => {
            clearTimeout(longPressTimer);
        });

        // 添加新图标
        document.getElementById('addIcon').addEventListener('click', () => {
            document.getElementById('contextMenu').classList.remove('active');
            document.getElementById('addIconModal').classList.add('active');
        });

        function addNewIcon() {
            const iconUrl = document.getElementById('iconUrl').value;
            const pageUrl = document.getElementById('pageUrl').value;
            const name = document.getElementById('iconName').value;

            if (iconUrl && pageUrl && name) {
                const icon = { iconUrl, pageUrl, name };
                icons.push(icon);
                localStorage.setItem('icons', JSON.stringify(icons));
                renderIcons();
                document.getElementById('addIconModal').classList.remove('active');
            }
        }

        // 渲染图标
        function renderIcons() {
            const page = document.querySelector('.page[data-page="1"]');
            page.innerHTML = '';
            
            // 添加时钟小部件
            const clockWidget = document.createElement('div');
            clockWidget.className = 'widget';
            clockWidget.id = 'clockWidget';
            clockWidget.innerHTML = `
                <div id="clock" style="font-size: 32px;">12:00</div>
                <div id="date">2025年2月23日</div>
            `;
            page.appendChild(clockWidget);

            // 渲染其他图标
            icons.forEach((icon, index) => {
                const iconElement = document.createElement('div');
                iconElement.className = 'icon';
                iconElement.innerHTML = `
                    <div class="icon-circle">
                        <span class="material-icons">${icon.name === '安装程序' ? 'install_desktop' : icon.name === '相册' ? 'photo_library' : icon.name === '浏览器' ? 'public' : icon.name === '计算器' ? 'calculate' : 'access_time'}</span>
                    </div>
                    <span class="icon-name">${icon.name}</span>
                `;

                iconElement.addEventListener('click', () => {
                    window.open(icon.pageUrl, '_blank');
                });

                let longPress = false;
                iconElement.addEventListener('touchstart', () => {
                    longPress = false;
                    setTimeout(() => {
                        longPress = true;
                        iconElement.classList.add('dragging');
                    }, 500);
                });

                iconElement.addEventListener('touchend', () => {
                    if (longPress) {
                        if (confirm('是否删除此图标？')) {
                            icons.splice(index, 1);
                            localStorage.setItem('icons', JSON.stringify(icons));
                            renderIcons();
                        }
                    }
                    iconElement.classList.remove('dragging');
                });

                page.appendChild(iconElement);
            });
        }

        // 初始化渲染
        renderIcons();

        // 关闭模态窗口
        document.querySelectorAll('.modal').forEach(modal => {
            modal.addEventListener('click', e => {
                if (e.target === modal) {
                    modal.classList.remove('active');
                }
            });
        });

     // 处理 .ner 文件上传
        document.getElementById('fileInput').addEventListener('change', function(event) {
            const file = event.target.files[0];
            if (file && file.name.endsWith('.ner')) {
                const reader = new FileReader();
                reader.onload = function(e) {
                    const data = e.target.result;
                    JSZip.loadAsync(data).then(function(zip) {
                        zip.file("appmessage.json").async("string").then(function(content) {
                            const appInfo = JSON.parse(content);
                            const iconUrl = `data:image/png;base64,${zip.file(appInfo.icons['48']).async("base64")}`;
                            const appEntry = `data:text/html;base64,${zip.file(appInfo.entry).async("base64")}`;

                            const newIcon = {
                                iconUrl: iconUrl,
                                pageUrl: appEntry,
                                name: appInfo.name
                            };

                            icons.push(newIcon);
                            localStorage.setItem('icons', JSON.stringify(icons));
                            renderIcons();
                        });
                    });
                };
                reader.readAsArrayBuffer(file);
            }
        });
      // 多任务列表
const taskManager = document.getElementById('taskManager');
const taskList = document.getElementById('taskList');

// 监听上滑手势
let startY = 0;
let isSwiping = false;

desktop.addEventListener('touchstart', e => {
    startY = e.touches[0].clientY;
    isSwiping = true;
});

desktop.addEventListener('touchmove', e => {
    if (!isSwiping) return;

    const diff = startY - e.touches[0].clientY;
    if (diff > 50) { // 上滑超过50px
        isSwiping = false;
        showTaskManager();
    }
});

desktop.addEventListener('touchend', () => {
    isSwiping = false;
});
